@@ -1,43 +1,28 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001-2010 Christoph Cullmann <cullmann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATE_MODEMANAGER_H
 #define KATE_MODEMANAGER_H
 
-#include <QStringList>
-#include <QPointer>
+#include "ktexteditor_export.h"
+
 #include <QHash>
+#include <QPointer>
+#include <QStringList>
 
 #include <KLocalizedString>
 
-#include "katedialogs.h"
-
 namespace KTextEditor
 {
-class DocumentPrivate;
+class Document;
 }
 
 class KateFileType
 {
 public:
-    int number = -1;
     QString name;
     QString section;
     QStringList wildcards;
@@ -85,10 +70,9 @@ public:
     void save(const QList<KateFileType *> &v);
 
     /**
-     * get the right fileType for the given document
-     * -1 if none found !
+     * @return the right KateFileType name for the given document or an empty string if none found
      */
-    QString fileType(KTextEditor::DocumentPrivate *doc, const QString &fileToReadFrom);
+    QString fileType(KTextEditor::Document *doc, const QString &fileToReadFrom);
 
     /**
      * Don't store the pointer somewhere longer times, won't be valid after the next update()
@@ -104,9 +88,12 @@ public:
     }
 
 private:
-    QString wildcardsFind(const QString &fileName);
+    friend class KateModeManagerTest;
+    friend class KateModeManagerBenchmark;
+
+    KTEXTEDITOR_EXPORT QString wildcardsFind(const QString &fileName) const; // exported for testing
+    KTEXTEDITOR_EXPORT QString mimeTypesFind(const QString &mimeTypeName) const; // exported for testing
 
-private:
     QList<KateFileType *> m_types;
     QHash<QString, KateFileType *> m_name2Type;
 };
